#
# spec file for package mandoc
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mandoc
Version:        1.14.5
Release:        lp152.2.2
Summary:        UNIX manpage compiler
License:        ISC
Group:          Productivity/Publishing/Troff
URL:            http://mandoc.bsd.lv/
Source:         http://mandoc.bsd.lv/snapshots/mandoc-%{version}.tar.gz
# PATCH-FEATURE-UPSTREAM empty_w-manpath.patch gh#neovim/neovim#11794 mcepl@suse.com
# Add man -w producing manpath (among many other things)
Patch0:         1.14.5-master.patch
BuildRequires:  zlib-devel
Provides:       man = %{version}
Conflicts:      man
Conflicts:      groff
Conflicts:      groff-full
Conflicts:      makewhat

%description
The mandoc manpage compiler toolset (formerly called "mdocml")
is a suite of tools compiling mdoc(7), the roff(7) macro language
of choice for BSD manual pages, and man(7), the predominant
historical language for UNIX manuals.

It includes a man(1) manual viewer and additional tools.
For general information, see <http://mandoc.bsd.lv/>.

%prep
%setup -q
%autopatch -p1

%build
%{?!make_build:%define make_build make %{?_smp_mflags} V=1 VERBOSE=1}
export CPPFLAGS="%{optflags}"
export CFLAGS="%optflags"
%configure
%make_build

%install
%make_install MANDIR=%{_mandir} BINDIR=%{_bindir} SBINDIR=%{_sbindir}
cp -fv %{buildroot}%{_bindir}/apropos %{_tmppath}/
mv -fv %{_tmppath}/apropos %{buildroot}%{_sbindir}/makewhatis

# ghost
: > %{buildroot}%{_mandir}/mandoc.db

%post
%{_sbindir}/makewhatis

%filetriggerin -p <lua> -- %{_mandir}
-- TODO: replace with rpm.execute after rpm 4.15
function execute(path, ...)
  local pid = posix.fork()
  if pid == 0 then
     posix.exec(path, ...)
     io.write(path, ": exec failed: ", posix.errno(), "\n")
     os.exit(1)
  end
  if not pid then
     error(path .. ": fork failed: " .. posix.errno() .. "\n")
  end
  posix.wait(pid)
end
--
-- no point registering individual files if we can call
-- makewhatis in %%post to catch all if
if posix.access("%{_mandir}/mandoc.db") then
    file = rpm.next_file()
    while file do
        if string.match(file, "%{_mandir}/man[^/]+/[^/]+%{?ext_man}$") then
            execute("%{_sbindir}/makewhatis", "-d", "%{_mandir}", file)
        end
        file = rpm.next_file()
    end
end

%filetriggerun -p <lua> -- %{_mandir}
-- TODO: replace with rpm.execute after rpm 4.15
function execute(path, ...)
  local pid = posix.fork()
  if pid == 0 then
     posix.exec(path, ...)
     io.write(path, ": exec failed: ", posix.errno(), "\n")
     os.exit(1)
  end
  if not pid then
     error(path .. ": fork failed: " .. posix.errno() .. "\n")
  end
  posix.wait(pid)
end
--
if posix.access("%{_mandir}/mandoc.db") then
    file = rpm.next_file()
    while file do
        if string.match(file, "%{_mandir}/man[^/]+/[^/]+%{?ext_man}$") then
            execute("%{_sbindir}/makewhatis", "-u", "%{_mandir}", file)
        end
        file = rpm.next_file()
    end
end

%files
%license LICENSE
%doc NEWS TODO
%{_bindir}/apropos
%{_bindir}/demandoc
%{_bindir}/man
%{_bindir}/mandoc
%{_bindir}/soelim
%{_bindir}/whatis
%{_sbindir}/makewhatis
%{_mandir}/man1/*.1%{?ext_man}
%{_mandir}/man5/*.5%{?ext_man}
%{_mandir}/man7/*.7%{?ext_man}
%{_mandir}/man8/*.8%{?ext_man}
%ghost %{_mandir}/mandoc.db

%changelog
* Mon Feb 10 2020 Matej Cepl <mcepl@suse.com>
- Add 1.14.5-master.patch containing among many other things fix
  allowing running ``man -w`` to get manpath.
  (gh#neovim/neovim#11794)
* Fri Jan 31 2020 Matej Cepl <mcepl@suse.com>
- Conflict also groff-full
* Fri Jan 10 2020 Ludwig Nussel <lnussel@suse.de>
- get rid of alternatives altogether, just conflict (boo#1160568)
* Thu Jan  9 2020 Ludwig Nussel <lnussel@suse.de>
- update-alternatives --remove must be in %%postun
- own mandoc.db
- add file triggers to update mandoc.db
* Mon Dec 16 2019 Matej Cepl <mcepl@suse.com>
- Add %%{_sbindir}/makewhatis to the alternatives mechanism to
  avoid conflict with the mandoc package.
* Sun Mar 10 2019 Matej Cepl <mcepl@suse.com>
- This package is meant as an alternative lightweight replacement
  for man-pages package. It does not have that many dependencies,
  it is written in C, see http://mandoc.bsd.lv/ for more.
- Update to the 1.14.5 release proper:
  * The apropos(1) utility now accepts case-insensitive extended
    regular expressions by default, improving POSIX compliance
    (thanks to Wolfram Schneider for the suggestion).
  * The new man(1) -O tag[=term] output option opens a page at the
    definition of a term (thanks to Klemens Nanni for the suggestion).
  * The output from tbl(7) has been significantly improved in both
    the HTML and the UTF-8 output modes (thanks to Pali Rohar for
    many reports and suggestions).
  * Several syntax errors have been fixed in HTML output and the
    HTML output code quality has been further improved, in particular
    with respect to paragraphs, tagged lists, and tooltips
    (thanks to John Gardner for significant help).
  * Low-level roff(7) support has been further improved such that
    mandoc can now handle the manual pages of the groff package.
  * Many bugs have been fixed.
* Wed Mar  6 2019 Matej Cepl <mcepl@suse.com>
- Upgrade to 1.14.5rc1. Changes too many to enlist here, for the
  complete list see file NEWS in the package.
- Add Provides and Conflicts man.
- Add alternatives for all commands and manpages.
* Wed Mar  6 2019 Matej Cepl <mcepl@suse.com>
- Fix SPEC file according to the review by werner@suse.com. Thank
  you!
* Wed Nov 28 2018 Matej Cepl <mcepl@suse.com>
- Initial package of mandoc 1.14.4
